pub struct Day12 { /* private fields */ }Expand description
2025 Day 12: Checking region sizes.
The solution assumes that each present shape can be treated as a solid 3x3 square. This makes the implementation trivial and much faster than a general solution to 2D bin packing (which is NP-complete).
Implementations